@@ -43,7 +43,7 @@ Coro_return_chat_message = Callable[[], Coroutine[Message.from_ws, None, None]]
 Coro_return_Any = Callable[[], Coroutine[Any, None, None]]
 Coro_return_None = Callable[[], Coroutine[None, None, None]]
 
-version = '0.0.38'
+version = '0.0.40'
 
 class Bot:
     __slots__ = (
@@ -70,7 +70,9 @@ class Bot:
         ignore_chats: dict[str, list[str]] = {}
     ):
         init()
-        load_dotenv()
+        # load_dotenv is not identifying the .env on project folder,
+        # so I use Path to get the absolute .env path
+        load_dotenv(Path('.env').absolute())
         try:
             self._email    = email    or environ['EMAIL']
             self._password = password or environ['PASSWORD']
