@@ -23,7 +23,9 @@ from .exceptions import (
     AminoSays
 )
 
-ignore_codes = []
+ignore_codes = [
+    1628 # Sorry, you cannot pick this member..
+]
 headers: dict[str, str] = {'NDCDEVICEID': '0184a516841ba77a5b4648de2cd0dfcb30ea46dbb4e911a6ed122578b14c7b662c59f9a2c83101f5a1'}
 actual_com:  str | None = None
 actual_chat: str | None = None
@@ -45,10 +47,10 @@ def get_value(
     convert: Any | None = None
 ) -> Any | None:
 
-    tmp = None
     with suppress(KeyError):
-        for i in k:
-            tmp = d[i]
+        tmp = d[k[0]]
+        for i in k[1:]:
+            tmp = tmp[i]
 
         if convert:
             return convert(tmp)
@@ -112,7 +114,8 @@ async def _req(
         data             = dumps(data) if need_dumps else data,
         headers          = headers,
     ) as res:
-        if res.status < 400 and (j := await res.json(loads=loads))['api:statuscode']:
+        if res.status >= 400 and (j := await res.json(loads=loads))['api:statuscode'] and j['api:statuscode'] not in ignore_codes:
+            print(j, ignore_codes, j not in  ignore_codes)
             raise AminoSays(f"{j['api:message']}. Code: {j['api:statuscode']}")
         if return_ == 'json':
             return await res.json(loads=loads)
